@@ -75,7 +75,8 @@ controller_params = ["--nodb", "--hwm=1", "--scheme=lru",
 # At scale we can run out of open file handles or run out of user
 # processes. This tries to adjust this limits for each IPython worker
 # within available hard limits.
-target_procs = 50000
+# Match target_procs to OSX limits for a default.
+target_procs = 10240
 resource_cmds = ["import resource",
                  "cur_proc, max_proc = resource.getrlimit(resource.RLIMIT_NPROC)",
                  "target_proc = min(max_proc, %s) if max_proc > 0 else %s" % (target_procs, target_procs),
@@ -119,8 +120,12 @@ class BcbioLSFEngineSetLauncher(launcher.LSFEngineSetLauncher):
     def start(self, n):
         self.context["cores"] = self.cores
         if self.mem:
+            # lsf.conf can specify nonstandard units for memory reservation
             lsf_unit = lsf.get_lsf_units(resource=True)
             mem = utils.convert_mb(float(self.mem) * 1024, lsf_unit)
+            # check if memory reservation is per core or per job
+            if lsf.per_core_reservation():
+                mem = mem / self.cores
             self.context["mem"] = '#BSUB -R "rusage[mem=%s]"' % mem
         else:
             self.context["mem"] = ""
@@ -384,7 +389,7 @@ class BcbioSLURMControllerLauncher(SLURMLauncher, launcher.BatchClusterAppMixin)
     def start(self):
         self.context["account"] = self.account
         self.context["timelimit"] = self.timelimit
-        self.context["mem"] = "#SBATCH --mem=%d" % DEFAULT_MEM_PER_CPU
+        self.context["mem"] = "#SBATCH --mem=%d" % (8 * DEFAULT_MEM_PER_CPU)
         self.context["tag"] = self.tag if self.tag else "bcbio"
         self.context["resources"] = "\n".join(["#SBATCH --%s" % r.strip()
                                                for r in str(self.resources).split(";")
